# PHAST WEB SERVICES

![Phast Web Services](https://www.dnvgl.com/Images/Phast-process-hazard-analysis-software_1000x500_tcm8-147208.jpg)

## INTRODUCTION

Phast is the world's most comprehensive process hazard analysis software which models the progress of a potential incident from the initial release to far-field dispersion including modelling of pool spreading and evaporation and resulting flammable and toxic effects. In Phast Web Services we have taken the same state of the art consequence modelling calculations and made them available as web services so you can use them in your own applications.

## CONSEQUENCE ANALYSIS

## WE LOVE CONSEQUENCE ANALYSIS

## WE REALLY, REALLY DO

We built web services for various consequence calculations so you don't have to.

We have services available for:

- Discharge
- Toxic/flammable gas dispersion
- Fire and explosion modelling
